@@ -21,3 +21,7 @@ class IdentifierType(StrEnum):
     @classmethod
     def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
+
+    @property
+    def column(self) -> str:
+        return self.value
