@@ -12,8 +12,8 @@ from maleo.schemas.mixins.filter import convert as convert_filter
 from maleo.schemas.mixins.general import Codes, Order
 from maleo.schemas.mixins.hierarchy import IsRoot, IsParent, IsChild, IsLeaf
 from maleo.schemas.mixins.identity import (
+    IdentifierMixin,
     DataIdentifier,
-    IdentifierTypeValue,
     Ids,
     UUIDs,
     ParentId,
@@ -23,6 +23,7 @@ from maleo.schemas.mixins.identity import (
 )
 from maleo.schemas.mixins.sort import convert as convert_sort
 from maleo.schemas.mixins.timestamp import LifecycleTimestamp, DataTimestamp
+from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
 from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
@@ -35,7 +36,7 @@ from maleo.types.integer import OptInt, OptListOfInts
 from maleo.types.string import OptListOfStrs, OptStr
 from maleo.types.uuid import OptListOfUUIDs
 from ..enums.medical_role import IdentifierType
-from ..mixins.medical_role import Code, Key, Name
+from ..mixins.medical_role import Code, Key, Name, MedicalRoleIdentifier
 from ..types.medical_role import IdentifierValueType
 
 
@@ -136,7 +137,7 @@ class ReadMultipleParameter(
         return params
 
 
-class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValueType]):
+class ReadSingleParameter(BaseReadSingleParameter[MedicalRoleIdentifier]):
     @overload
     @classmethod
     def new(
@@ -164,6 +165,15 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
@@ -173,8 +183,9 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier_type=identifier_type,
-            identifier_value=identifier_value,
+            identifier=MedicalRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
             statuses=statuses,
             use_cache=use_cache,
         )
@@ -212,25 +223,138 @@ class UpdateDataMixin(BaseModel, Generic[UpdateDataT]):
 
 class UpdateParameter(
     UpdateDataMixin[UpdateDataT],
-    IdentifierTypeValue[
-        IdentifierType,
-        IdentifierValueType,
-    ],
+    IdentifierMixin[MedicalRoleIdentifier],
     Generic[UpdateDataT],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter":
+        return cls(
+            identifier=MedicalRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
+            data=data,
+        )
 
 
 class StatusUpdateParameter(
-    BaseStatusUpdateParameter[IdentifierType, IdentifierValueType],
+    BaseStatusUpdateParameter[MedicalRoleIdentifier],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter":
+        return cls(
+            identifier=MedicalRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
+            type=type,
+        )
 
 
-class DeleteSingleParameter(
-    BaseDeleteSingleParameter[IdentifierType, IdentifierValueType]
-):
-    pass
+class DeleteSingleParameter(BaseDeleteSingleParameter[MedicalRoleIdentifier]):
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.ID], identifier_value: int
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.UUID], identifier_value: UUID
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter": ...
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter":
+        return cls(
+            identifier=MedicalRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            )
+        )
 
 
 class BaseMedicalRoleSchema(
@@ -280,7 +404,7 @@ OptKeyOrFullSchema = KeyOrFullSchema | None
 AnyMedicalRoleSchemaType = Type[StandardMedicalRoleSchema] | Type[FullMedicalRoleSchema]
 
 
-# User Type Schemas
+# Medical Role Schemas
 AnyMedicalRoleSchema = StandardMedicalRoleSchema | FullMedicalRoleSchema
 MedicalRoleSchemaT = TypeVar("MedicalRoleSchemaT", bound=AnyMedicalRoleSchema)
 
@@ -300,7 +424,7 @@ OptListOfAnyMedicalRoleSchemasT = TypeVar(
 )
 
 
-# User Type key and Schemas
+# Medical Role key and Schemas
 AnyMedicalRole = MedicalRole | AnyMedicalRoleSchema
 AnyMedicalRoleT = TypeVar("AnyMedicalRoleT", bound=AnyMedicalRole)
 
