@@ -18,8 +18,8 @@ from maleo.enums.status import (
 from maleo.schemas.mixins.filter import convert as convert_filter
 from maleo.schemas.mixins.general import Order
 from maleo.schemas.mixins.identity import (
+    IdentifierMixin,
     DataIdentifier,
-    IdentifierTypeValue,
     Ids,
     UUIDs,
     Keys,
@@ -27,6 +27,7 @@ from maleo.schemas.mixins.identity import (
 )
 from maleo.schemas.mixins.sort import convert as convert_sort
 from maleo.schemas.mixins.timestamp import LifecycleTimestamp, DataTimestamp
+from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
 from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
@@ -38,7 +39,7 @@ from maleo.types.integer import OptInt, OptListOfInts
 from maleo.types.string import OptListOfStrs, OptStr
 from maleo.types.uuid import OptListOfUUIDs
 from ..enums.service import IdentifierType
-from ..mixins.service import ServiceType, Category, Key, Name, Secret
+from ..mixins.service import ServiceType, Category, Key, Name, Secret, ServiceIdentifier
 from ..types.service import IdentifierValueType
 
 
@@ -94,7 +95,7 @@ class ReadMultipleParameter(
         return params
 
 
-class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValueType]):
+class ReadSingleParameter(BaseReadSingleParameter[ServiceIdentifier]):
     @overload
     @classmethod
     def new(
@@ -122,6 +123,15 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
@@ -131,8 +141,7 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier_type=identifier_type,
-            identifier_value=identifier_value,
+            identifier=ServiceIdentifier(type=identifier_type, value=identifier_value),
             statuses=statuses,
             use_cache=use_cache,
         )
@@ -170,25 +179,132 @@ class UpdateDataMixin(BaseModel, Generic[UpdateDataT]):
 
 class UpdateParameter(
     UpdateDataMixin[UpdateDataT],
-    IdentifierTypeValue[
-        IdentifierType,
-        IdentifierValueType,
-    ],
+    IdentifierMixin[ServiceIdentifier],
     Generic[UpdateDataT],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter":
+        return cls(
+            identifier=ServiceIdentifier(type=identifier_type, value=identifier_value),
+            data=data,
+        )
 
 
 class StatusUpdateParameter(
-    BaseStatusUpdateParameter[IdentifierType, IdentifierValueType],
+    BaseStatusUpdateParameter[ServiceIdentifier],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter":
+        return cls(
+            identifier=ServiceIdentifier(type=identifier_type, value=identifier_value),
+            type=type,
+        )
 
 
-class DeleteSingleParameter(
-    BaseDeleteSingleParameter[IdentifierType, IdentifierValueType]
-):
-    pass
+class DeleteSingleParameter(BaseDeleteSingleParameter[ServiceIdentifier]):
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.ID], identifier_value: int
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.UUID], identifier_value: UUID
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter": ...
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter":
+        return cls(
+            identifier=ServiceIdentifier(type=identifier_type, value=identifier_value)
+        )
 
 
 class BaseServiceSchema(
@@ -239,7 +355,7 @@ OptKeyOrFullSchema = KeyOrFullSchema | None
 AnyServiceSchemaType = Type[StandardServiceSchema] | Type[FullServiceSchema]
 
 
-# User Type Schemas
+# Service Schemas
 AnyServiceSchema = StandardServiceSchema | FullServiceSchema
 ServiceSchemaT = TypeVar("ServiceSchemaT", bound=AnyServiceSchema)
 
@@ -257,7 +373,7 @@ OptListOfAnyServiceSchemasT = TypeVar(
 )
 
 
-# User Type key and Schemas
+# Service key and Schemas
 AnyService = ServiceKey | AnyServiceSchema
 AnyServiceT = TypeVar("AnyServiceT", bound=AnyService)
 
