@@ -11,8 +11,8 @@ from maleo.enums.status import (
 from maleo.schemas.mixins.filter import convert as convert_filter
 from maleo.schemas.mixins.general import Order
 from maleo.schemas.mixins.identity import (
+    IdentifierMixin,
     DataIdentifier,
-    IdentifierTypeValue,
     Ids,
     UUIDs,
     Keys,
@@ -20,6 +20,7 @@ from maleo.schemas.mixins.identity import (
 )
 from maleo.schemas.mixins.sort import convert as convert_sort
 from maleo.schemas.mixins.timestamp import LifecycleTimestamp, DataTimestamp
+from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
 from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
     ReadPaginatedMultipleParameter,
@@ -31,7 +32,7 @@ from maleo.types.integer import OptInt, OptListOfInts
 from maleo.types.string import OptListOfStrs, OptStr
 from maleo.types.uuid import OptListOfUUIDs
 from ..enums.system_role import IdentifierType
-from ..mixins.system_role import Key, Name
+from ..mixins.system_role import Key, Name, SystemRoleIdentifier
 from ..types.system_role import IdentifierValueType
 
 
@@ -81,7 +82,7 @@ class ReadMultipleParameter(
         return params
 
 
-class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValueType]):
+class ReadSingleParameter(BaseReadSingleParameter[SystemRoleIdentifier]):
     @overload
     @classmethod
     def new(
@@ -109,6 +110,15 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
         use_cache: bool = True,
     ) -> "ReadSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        statuses: ListOfDataStatuses = FULL_DATA_STATUSES,
+        use_cache: bool = True,
+    ) -> "ReadSingleParameter": ...
     @classmethod
     def new(
         cls,
@@ -118,8 +128,9 @@ class ReadSingleParameter(BaseReadSingleParameter[IdentifierType, IdentifierValu
         use_cache: bool = True,
     ) -> "ReadSingleParameter":
         return cls(
-            identifier_type=identifier_type,
-            identifier_value=identifier_value,
+            identifier=SystemRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
             statuses=statuses,
             use_cache=use_cache,
         )
@@ -147,25 +158,138 @@ class UpdateDataMixin(BaseModel, Generic[UpdateDataT]):
 
 class UpdateParameter(
     UpdateDataMixin[UpdateDataT],
-    IdentifierTypeValue[
-        IdentifierType,
-        IdentifierValueType,
-    ],
+    IdentifierMixin[SystemRoleIdentifier],
     Generic[UpdateDataT],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        data: UpdateDataT,
+    ) -> "UpdateParameter":
+        return cls(
+            identifier=SystemRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
+            data=data,
+        )
 
 
 class StatusUpdateParameter(
-    BaseStatusUpdateParameter[IdentifierType, IdentifierValueType],
+    BaseStatusUpdateParameter[SystemRoleIdentifier],
 ):
-    pass
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.ID],
+        identifier_value: int,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.UUID],
+        identifier_value: UUID,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter": ...
+    @classmethod
+    def new(
+        cls,
+        identifier_type: IdentifierType,
+        identifier_value: IdentifierValueType,
+        type: ResourceOperationStatusUpdateType,
+    ) -> "StatusUpdateParameter":
+        return cls(
+            identifier=SystemRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            ),
+            type=type,
+        )
 
 
-class DeleteSingleParameter(
-    BaseDeleteSingleParameter[IdentifierType, IdentifierValueType]
-):
-    pass
+class DeleteSingleParameter(BaseDeleteSingleParameter[SystemRoleIdentifier]):
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.ID], identifier_value: int
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: Literal[IdentifierType.UUID], identifier_value: UUID
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls,
+        identifier_type: Literal[IdentifierType.KEY, IdentifierType.NAME],
+        identifier_value: str,
+    ) -> "DeleteSingleParameter": ...
+    @overload
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter": ...
+    @classmethod
+    def new(
+        cls, identifier_type: IdentifierType, identifier_value: IdentifierValueType
+    ) -> "DeleteSingleParameter":
+        return cls(
+            identifier=SystemRoleIdentifier(
+                type=identifier_type, value=identifier_value
+            )
+        )
 
 
 class BaseSystemRoleSchema(
@@ -213,7 +337,7 @@ OptKeyOrFullSchema = KeyOrFullSchema | None
 AnySystemRoleSchemaType = Type[StandardSystemRoleSchema] | Type[FullSystemRoleSchema]
 
 
-# User Type Schemas
+# System Role Schemas
 AnySystemRoleSchema = StandardSystemRoleSchema | FullSystemRoleSchema
 SystemRoleSchemaT = TypeVar("SystemRoleSchemaT", bound=AnySystemRoleSchema)
 
@@ -233,7 +357,7 @@ OptListOfAnySystemRoleSchemasT = TypeVar(
 )
 
 
-# User Type key and Schemas
+# System Role key and Schemas
 AnySystemRole = SystemRole | AnySystemRoleSchema
 AnySystemRoleT = TypeVar("AnySystemRoleT", bound=AnySystemRole)
 
